# Example Project Documentation

This is an example project to demonstrate the use of the documentation template.

## Quick Links

- [Installation](./getting_started/installation.md)
- [Quick Start](./getting_started/quickstart.md)
- [API Reference][tauth]
- GitHub Repository
- PyPI Package
- ...
